@@ -185,13 +185,11 @@ class APIClient:
     def server_delete(self, machine_id: str) -> None:
         """Delete a server."""
         url = self.api_endpoint + api.ServerDelete.url.format(machine_id=machine_id)
-        response = self._httpx_client.post(url)
+        response = self._httpx_client.delete(url)
         _handle_response(response)
 
     def server_forget(self, machine_id: str) -> None:
-        """
-        Forget about a destroyed/deleted server.
-        """
+        """Forget about a deleted server to hide it from view."""
         url = self.api_endpoint + api.ServerForget.url.format(machine_id=machine_id)
         response = self._httpx_client.post(url)
         _handle_response(response)
@@ -244,6 +242,14 @@ class APIClient:
         response_object = api.OperatingSystems.Response.parse_obj(response.json())
         return response_object
 
+    def regions(self) -> api.Regions.Response:
+        """Returns regions that you can launch a server in."""
+        url = self.api_endpoint + api.Regions.url
+        response = self._httpx_client.get(url)
+        _handle_response(response)
+        response_object = api.Regions.Response.parse_obj(response.json())
+        return response_object
+
     def changelog(self) -> str:
         """Returns the API changelog."""
         url = self.api_endpoint + "/changelog"
