@@ -279,6 +279,10 @@ def pretty_machine_info(info: Dict[str, Any]) -> str:
     return msg
 
 
+def epoch_to_human(epoch: int) -> str:
+    return time.strftime("%Y-%m-%d %H:%M:%S %z", time.localtime(epoch))
+
+
 def print_machine_info(info: "api.ServerInfo.Response") -> None:
     if info.hostname != "":
         typer.echo(f"Hostname: {info.hostname}")
@@ -296,13 +300,16 @@ def print_machine_info(info: "api.ServerInfo.Response") -> None:
         typer.echo("IPv4: (Not yet assigned)")
     typer.echo(f"Region: {info.region}")
     typer.echo(f"Flavor: {info.flavor.slug}")
-    human_expiration = time.strftime(
-        "%Y-%m-%d %H:%M:%S %z", time.localtime(info.expiration)
-    )
-    typer.echo(f"Expiration: {info.expiration} ({human_expiration})")
+    typer.echo(f"Expiration: {epoch_to_human(info.expiration)}")
     typer.echo(f"Token: {info.token}")
-    if info.deleted:
+    if info.deleted_at != 0 or info.deleted:
         typer.echo("Server was deleted!")
+        if info.deleted_at != 0:
+            typer.echo(f"Server deleted at: {epoch_to_human(info.deleted_at)}")
+        if info.deleted_by is not None:
+            typer.echo(f"Server deleted by: {info.deleted_by.value}")
+        if info.forgotten_at is not None:
+            typer.echo(f"Server forgotten at: {info.forgotten_at}")
     else:
         typer.echo(f"Running: {info.running}")
         time_to_live = info.expiration - int(time.time())
@@ -317,6 +324,9 @@ def server_list(
     local: bool = typer.Option(
         True, help="List older servers not associated to token."
     ),
+    show_forgotten: bool = typer.Option(
+        False, help="Show deleted and forgotten servers."
+    ),
 ) -> None:
     """List all locally known servers and all servers under the given token."""
     from .api_client import APIClient
@@ -339,6 +349,9 @@ def server_list(
     printed_machine_ids = []
 
     for info in server_infos:
+        if not show_forgotten and info.forgotten_at is not None:
+            continue
+
         typer.echo()
 
         hostname = info.hostname
@@ -408,6 +421,8 @@ def _get_machine_id(machine_id: str, hostname: str, token: str) -> str:
     api_client = APIClient(api_endpoint=get_api_endpoint())
 
     for server in api_client.servers_launched_from_token(token=_token).servers:
+        if server.forgotten_at is not None:
+            continue
         if server.hostname == hostname:
             return server.machine_id
 
@@ -540,7 +555,7 @@ def rebuild(
 
 @server_cli.command()
 def flavors() -> None:
-    """Show available flavors."""
+    """Shows available flavors."""
     from .api_client import APIClient
 
     api_client = APIClient(api_endpoint=get_api_endpoint())
@@ -557,7 +572,18 @@ def operating_systems() -> None:
     api_client = APIClient(api_endpoint=get_api_endpoint())
     os_list = api_client.operating_systems().operating_systems
     for operating_system in os_list:
-        typer.echo(operating_system)
+        typer.echo(f"{operating_system}")
+
+
+@server_cli.command()
+def regions() -> None:
+    """Shows regions that servers can be launched in."""
+    from .api_client import APIClient
+
+    api_client = APIClient(api_endpoint=get_api_endpoint())
+    regions = api_client.regions().regions
+    for region in regions:
+        typer.echo(f"{region}: {regions[region].name}")
 
 
 def load_token(token: str) -> str:
