@@ -82,9 +82,11 @@ class Token:
         """Returns support messages for/from the token."""
         self.api_client.token_send_message(token=self.token, message=message)
 
-    def servers(self) -> List[Server]:
+    def servers(self, show_forgotten: bool = False) -> List[Server]:
         server_classes: List[Server] = []
         for server in self.api_client.servers_launched_from_token(self.token).servers:
+            if not show_forgotten and server.forgotten_at is not None:
+                continue
             server_classes.append(
                 Server(
                     machine_id=server.machine_id,
@@ -136,6 +138,10 @@ class Client:
         """Returns available operating systems."""
         return self.api_client.operating_systems()
 
+    def regions(self) -> api.Regions.Response:
+        """Returns regions that servers can be launched in."""
+        return self.api_client.regions()
+
     def server_quote(self, days: int, flavor: str) -> api.ServerQuote.Response:
         """Get a quote for how much a server will cost."""
         return self.api_client.server_quote(days=days, flavor=flavor)
