@@ -59,3 +59,10 @@ class TokenInfo(BaseModel):
     burn_rate_usd: str
     days_remaining: int
     servers: int
+
+
+class Region(BaseModel):
+    # Unique string to identify the region that's sort of human readable.
+    slug: str
+    # Actually human readable string describing the region.
+    name: str
